@@ -2,7 +2,7 @@
 import argparse
 from linksim_src import Url
 from linksim_src.ele import detect
-
+from termcolor import  colored
 
 parser = argparse.ArgumentParser(usage="Manager project, can create git , sync , encrypt your repo")
 parser.add_argument("-u","--url",default="", help="get group")
@@ -22,9 +22,9 @@ def main():
                     print(l, l.title)
                 print()
         else:
-            for _,v in detect(args.url).items():
+            for k,v in detect(args.url).items():
                 css, e = v
-                print("--"*3, css)
+                print(colored("[%s]"%k, "green", attrs=['bold']),"--"*3, colored(css, 'green',attrs=['underline']))
                 print(e)
 
 if __name__ == "__main__":
